@@ -31,6 +31,7 @@
 #define _GNU_SOURCE
 
 #include "dgamelaunch.h"
+#include "config.h"
 #include "ttyplay.h"
 #include "ttyrec.h"
 
@@ -49,7 +50,7 @@
 #include <sys/wait.h>
 #include <sys/ioctl.h>          /* ttyrec */
 #include <sys/stat.h>
-
+#include <libgen.h>
 #include <stdlib.h>
 #include <curses.h>
 
@@ -67,10 +68,6 @@
 # include <pty.h>
 #endif
 
-#ifndef ARRAY_SIZE
-# define ARRAY_SIZE(x) (sizeof(x) / sizeof(x[0]))
-#endif
-
 #include <fcntl.h>
 #include <pwd.h>
 #include <grp.h>
@@ -84,7 +81,6 @@
 #include <unistd.h>
 #include <termios.h>
 
-#include "y.tab.h"
 extern FILE* yyin;
 extern int yyparse ();
 
@@ -92,6 +88,7 @@ extern int editor_main (int argc, char **argv);
 
 /* global variables */
 
+char * __progname;
 char rcfilename[80];
 
 int f_num = 0;
@@ -99,7 +96,7 @@ struct dg_user **users = NULL;
 struct dg_user *me = NULL;
 struct dg_banner banner;
 
-#if !(defined(__linux__) || defined(BSD))
+#ifndef HAVE_SETENV
 int
 mysetenv (const char* name, const char* value, int overwrite)
 {
@@ -120,7 +117,7 @@ mysetenv (const char* name, const char* value, int overwrite)
 }
 #else /* use native setenv */
 # define mysetenv setenv
-#endif /* !linux && !bsd */
+#endif
 
 /* ************************************************************* */
 /* for ttyrec */
@@ -128,7 +125,7 @@ mysetenv (const char* name, const char* value, int overwrite)
 void
 ttyrec_getpty ()
 {
-#ifdef USE_OPENPTY
+#ifdef HAVE_OPENPTY
   if (openpty (&master, &slave, NULL, NULL, NULL) == -1)
     graceful_exit (62);
 #else
@@ -246,7 +243,7 @@ loadbanner (struct dg_banner *ban)
       ban->len = 2;
       ban->lines = malloc (sizeof (char *));
       ban->lines[0] =
-        strdup ("### dgamelaunch " VERSION
+        strdup ("### dgamelaunch " PACKAGE_VERSION
                 " - network console game launcher");
       len = strlen(myconfig->banner) + ARRAY_SIZE("### NOTE: administrator has not installed a  file");
       ban->lines[1] = malloc(len);
@@ -277,9 +274,9 @@ loadbanner (struct dg_banner *ban)
                 bufnew[i] = *(b++);
               else
                 {
-                  strlcat (bufnew, VERSION, 80);
-                  b += 8;       /* skip the whole $VERSION string */
-                  i += ARRAY_SIZE (VERSION) - 1;
+                  strlcat (bufnew, PACKAGE_VERSION, 80);
+                  b += 8;       /* skip the whole $PACKAGE_VERSION string */
+                  i += ARRAY_SIZE (PACKAGE_VERSION) - 1;
 		  break;
                 }
 
@@ -796,6 +793,7 @@ autologin (char* user, char *pass)
     {
       loggedin = 1;
       snprintf (rcfilename, 80, "%srcfiles/%s.nethackrc", myconfig->dglroot, me->username);
+      setproctitle ("%s", me->username);
     }
   }
 }
@@ -858,6 +856,7 @@ loginprompt (int from_ttyplay)
     {
       loggedin = 1;
       snprintf (rcfilename, 80, "%srcfiles/%s.nethackrc", myconfig->dglroot, me->username);
+      setproctitle ("%s", me->username);
     }
   else 
   {
@@ -1006,6 +1005,7 @@ newuser ()
   loggedin = 1;
 
   snprintf (rcfilename, 80, "%srcfiles/%s.nethackrc", myconfig->dglroot, me->username);
+  setproctitle ("%s", me->username);
 
   if (access (rcfilename, R_OK) == -1)
     write_canned_rcfile (rcfilename);
@@ -1671,7 +1671,25 @@ main (int argc, char** argv)
   int c;
   int nhext = 0, nhauth = 0;
 
-  while ((c = getopt(argc, argv, "qh:pp:f:ae")) != -1)
+#ifndef HAVE_SETPROCTITLE
+  /* save argc, argv */
+  char** saved_argv;
+  int saved_argc, i;
+
+  saved_argc = argc;
+
+  saved_argv = malloc(sizeof(char**) * (argc + 1));
+  for (i = 0; i < argc; i++)
+    saved_argv[i] = strdup(argv[i]);
+  saved_argv[i] = '\0';
+  
+  compat_init_setproctitle(argc, argv);
+  argv = saved_argv;
+#endif
+
+  __progname = basename(strdup(argv[0]));
+
+  while ((c = getopt(argc, argv, "qh:pf:ae")) != -1)
   {
     switch (c)
     {
@@ -1700,6 +1718,13 @@ main (int argc, char** argv)
     }
   }
   
+  while (optind < argc)
+  {
+    size_t len = strlen(argv[optind]);
+    memset(argv[optind++], 0, len);
+  }
+  setproctitle ("(not logged in)");
+
   create_config();
 
   /* signal handlers */
@@ -1801,6 +1826,8 @@ main (int argc, char** argv)
   while (!purge_stale_locks())
     menuloop();
 
+  setproctitle ("%s [playing]", me->username);
+
   endwin ();
   signal(SIGWINCH, SIG_DFL);
 
