@@ -3,16 +3,11 @@
 #ifndef __DGAMELAUNCH_H
 #define __DGAMELAUNCH_H
 
+#include "config.h"
 #include <sys/param.h>
 #include <sys/types.h>
 #include <time.h>
 
-/* Default - should work everywhere */
-#if defined(__linux__) || defined(BSD)
-# define USE_OPENPTY
-# define NOSTREAMS
-#endif
-
 #ifndef ARRAY_SIZE
 # define ARRAY_SIZE(x) (sizeof(x) / sizeof(x[0]))
 #endif
@@ -103,6 +98,10 @@ extern int mysetenv (const char* name, const char* value, int overwrite);
 #else
 # define mysetenv setenv
 #endif
+#ifndef HAVE_SETPROCTITLE
+void compat_init_setproctitle(int argc, char *argv[]);
+void setproctitle(const char *fmt, ...);
+#endif
 
 /* strlcpy.c */
 extern size_t strlcpy (char *dst, const char *src, size_t siz);
